@@ -73,6 +73,12 @@
 #include <QtCore/QFileInfo>
 #include <QtCore/QSettings>
 
+#ifdef Q_OS_WIN
+static Qt::CaseSensitivity cs = Qt::CaseInsensitive;
+#else
+static Qt::CaseSensitivity cs = Qt::CaseSensitive;
+#endif
+
 class KStandardDirs::KStandardDirsPrivate
 {
 public:
@@ -322,7 +328,7 @@ void KStandardDirs::addPrefix( const QString& _dir, bool priority )
     if (dir.at(dir.length() - 1) != QLatin1Char('/'))
         dir += QLatin1Char('/');
 
-    if (!d->m_prefixes.contains(dir)) {
+    if (!d->m_prefixes.contains(dir, cs)) {
         priorityAdd(d->m_prefixes, dir, priority);
         d->m_dircache.clear();
     }
@@ -342,7 +348,7 @@ void KStandardDirs::addXdgConfigPrefix( const QString& _dir, bool priority )
     if (dir.at(dir.length() - 1) != QLatin1Char('/'))
         dir += QLatin1Char('/');
 
-    if (!d->xdgconf_prefixes.contains(dir)) {
+    if (!d->xdgconf_prefixes.contains(dir, cs)) {
         priorityAdd(d->xdgconf_prefixes, dir, priority);
         d->m_dircache.clear();
     }
@@ -362,7 +368,7 @@ void KStandardDirs::addXdgDataPrefix( const QString& _dir, bool priority )
     if (dir.at(dir.length() - 1) != QLatin1Char('/'))
         dir += QLatin1Char('/');
 
-    if (!d->xdgdata_prefixes.contains(dir)) {
+    if (!d->xdgdata_prefixes.contains(dir, cs)) {
         priorityAdd(d->xdgdata_prefixes, dir, priority);
         d->m_dircache.clear();
     }
@@ -410,7 +416,7 @@ bool KStandardDirs::addResourceType( const char *type,
     QByteArray typeBa = type;
     QStringList& rels = d->m_relatives[typeBa]; // find or insert
 
-    if (!rels.contains(copy)) {
+    if (!rels.contains(copy, cs)) {
         if (priority)
             rels.prepend(copy);
         else
@@ -436,7 +442,7 @@ bool KStandardDirs::addResourceDir( const char *type,
 
     QByteArray typeBa = type;
     QStringList &paths = d->m_absolutes[typeBa];
-    if (!paths.contains(copy)) {
+    if (!paths.contains(copy, cs)) {
         if (priority)
             paths.prepend(copy);
         else
@@ -469,7 +475,7 @@ QString KStandardDirs::findResource( const char *type,
     QString filename(_filename);
 #ifdef Q_OS_WIN
     if(strcmp(type, "exe") == 0) {
-      if(!filename.endsWith(QLatin1String(".exe")))
+      if(!filename.endsWith(QLatin1String(".exe"), Qt::CaseInsensitive))
         filename += QLatin1String(".exe");
     }
 #endif
@@ -557,7 +563,7 @@ QString KStandardDirs::findResourceDir( const char *type,
     QString filename(_filename);
 #ifdef Q_OS_WIN
     if(strcmp(type, "exe") == 0) {
-      if(!filename.endsWith(QLatin1String(".exe")))
+      if(!filename.endsWith(QLatin1String(".exe"), Qt::CaseInsensitive))
         filename += QLatin1String(".exe");
     }
 #endif
@@ -643,7 +649,7 @@ static void lookupDirectory(const QString& path, const QString &relPart,
                 }
                 if ( !bIsDir )
                 {
-                    if ( !unique || !relList.contains(relPart + fn) )
+                    if ( !unique || !relList.contains(relPart + fn, cs) )
                     {
                         list.append( pathfn );
                         relList.append( relPart + fn );
@@ -700,7 +706,7 @@ static void lookupDirectory(const QString& path, const QString &relPart,
             }
             if ( isReg )
             {
-                if (!unique || !relList.contains(relPart + fn))
+                if (!unique || !relList.contains(relPart + fn, cs))
                 {
                     list.append( pathfn );
                     relList.append( relPart + fn );
@@ -720,7 +726,7 @@ static void lookupDirectory(const QString& path, const QString &relPart,
             return; // File not found
         if ( S_ISREG( buff.st_mode))
         {
-            if (!unique || !relList.contains(relPart + fn))
+            if (!unique || !relList.contains(relPart + fn, cs))
             {
                 list.append( pathfn );
                 relList.append( relPart + fn );
@@ -1104,14 +1110,8 @@ QStringList KStandardDirs::KStandardDirsPrivate::resourceDirs(const char* type,
 
         const QStringList dirs = m_relatives.value(type);
         const QString typeInstallPath = installPath(type); // could be empty
-// better #ifdef incasesensitive_filesystem
-#ifdef Q_WS_WIN
-        const QString installdir = typeInstallPath.isEmpty() ? QString() : realPath(typeInstallPath).toLower();
-        const QString installprefix = installPath("kdedir").toLower();
-#else
         const QString installdir = typeInstallPath.isEmpty() ? QString() : realPath(typeInstallPath);
         const QString installprefix = installPath("kdedir");
-#endif
         if (!dirs.isEmpty())
         {
             bool local = true;
@@ -1128,13 +1128,9 @@ QStringList KStandardDirs::KStandardDirsPrivate::resourceDirs(const char* type,
                     for (QStringList::ConstIterator it2 = basedirs.begin();
                          it2 != basedirs.end(); ++it2)
                     {
-#ifdef Q_WS_WIN
-                        const QString path = realPath( *it2 + rest ).toLower();
-#else
                         const QString path = realPath( *it2 + rest );
-#endif
                         testdir.setPath(path);
-                        if ((local || testdir.exists()) && !candidates.contains(path))
+                        if ((local || testdir.exists()) && !candidates.contains(path, cs))
                             candidates.append(path);
                         local = false;
                     }
@@ -1153,22 +1149,18 @@ QStringList KStandardDirs::KStandardDirsPrivate::resourceDirs(const char* type,
                  pit != prefixList->end();
                  ++pit)
             {
-            if((*pit)!=installprefix||installdir.isEmpty())
+            if((*pit).compare(installprefix, cs) != 0 || installdir.isEmpty())
             {
                     for (QStringList::ConstIterator it = dirs.constBegin();
                          it != dirs.constEnd(); ++it)
                     {
                         if ((*it).startsWith(QLatin1Char('%')))
                             continue;
-#ifdef Q_WS_WIN
-                        const QString path = realPath( *pit + *it ).toLower();
-#else
                         const QString path = realPath( *pit + *it );
-#endif
                         testdir.setPath(path);
                         if (local && restrictionActive)
                             continue;
-                        if ((local || testdir.exists()) && !candidates.contains(path))
+                        if ((local || testdir.exists()) && !candidates.contains(path, cs))
                             candidates.append(path);
                     }
                     local = false;
@@ -1177,7 +1169,7 @@ QStringList KStandardDirs::KStandardDirsPrivate::resourceDirs(const char* type,
             {
                     // we have a custom install path, so use this instead of <installprefix>/<relative dir>
                 testdir.setPath(installdir);
-                    if(testdir.exists() && ! candidates.contains(installdir))
+                    if(testdir.exists() && ! candidates.contains(installdir, cs))
                         candidates.append(installdir);
             }
         }
@@ -1187,7 +1179,7 @@ QStringList KStandardDirs::KStandardDirsPrivate::resourceDirs(const char* type,
         if (!installdir.isEmpty()) {
             bool ok = true;
             foreach (const QString &s, candidates) {
-                if (installdir.startsWith(s)) {
+                if (installdir.startsWith(s, cs)) {
                     ok = false;
                     break;
                 }
@@ -1202,12 +1194,8 @@ QStringList KStandardDirs::KStandardDirsPrivate::resourceDirs(const char* type,
         {
             testdir.setPath(*it);
             if (testdir.exists()) {
-#ifdef Q_WS_WIN
-                const QString filename = realPath( *it ).toLower();
-#else
                 const QString filename = realPath( *it );
-#endif
-                if (!candidates.contains(filename)) {
+                if (!candidates.contains(filename, cs)) {
                     candidates.append(filename);
                 }
             }
@@ -1572,7 +1560,7 @@ QString KStandardDirs::relativeLocation(const char *type, const QString &absPath
 
     for (QStringList::ConstIterator it = candidates.begin();
          it != candidates.end(); ++it) {
-        if (fullPath.startsWith(*it)) {
+        if (fullPath.startsWith(*it, cs)) {
             return fullPath.mid((*it).length());
         }
     }
@@ -1706,7 +1694,7 @@ void KStandardDirs::addKDEDefaults()
     kdedirList.append(installPath("kdedir"));
 
     QString execPrefix(QFile::decodeName(EXEC_INSTALL_PREFIX));
-    if (!execPrefix.isEmpty() && !kdedirList.contains(execPrefix))
+    if (!execPrefix.isEmpty() && !kdedirList.contains(execPrefix, cs))
         kdedirList.append(execPrefix);
 #ifdef __linux__
     const QString linuxExecPrefix = executablePrefix();
@@ -1828,7 +1816,7 @@ void KStandardDirs::addKDEDefaults()
         // otherwise resourceDirs() will add kdedir/share/applications/kde4
         // as returned by installPath(), and that's incorrect.
         Q_FOREACH(const QString& dir, kdedirDataDirs) {
-            if (!xdgdirList.contains(dir))
+            if (!xdgdirList.contains(dir, cs))
                 xdgdirList.append(dir);
         }
     } else {
